@@ -394,6 +394,7 @@ inline bool TextSplit::emitterm(bool isspan, const string& w, int pos, size_t bt
 
     int l = int(w.length());
     if (l == 0 || l > o_maxWordLength) {
+        discarded(w, pos, btstart, btend, WORD_TOO_LONG);
         return true;
     }
     if (l == 1) {
@@ -523,16 +524,16 @@ inline bool TextSplit::doemit(bool spanerase, size_t _bp)
 
     if (m_wordLen) {
         // We have a current word. Remember it
-
-        if (int(m_words_in_span.size()) >= o_maxWordsInSpan) {
-            // Limit max span word count
-            spanerase = true;
-        }
-        
         if (!(o_noNumbers && m_inNumber)) {
             m_words_in_span.push_back({m_wordStart, m_wordStart + m_wordLen});
             m_wordpos++;
         }
+        if (int(m_words_in_span.size()) >= o_maxWordsInSpan) {
+            // Limit max span word count
+            spanerase = true;
+            discarded(m_span, m_spanpos, m_words_in_span[0].first, m_words_in_span.back().second,
+                      LONG_SPAN_TRUNCATED);
+        }
         m_wordLen = m_wordChars = 0;
     }
 
@@ -541,7 +542,7 @@ inline bool TextSplit::doemit(bool spanerase, size_t _bp)
         m_wordStart = int(m_span.length());
         return true;
     }
-
+    
     // Span is done (too long or span-terminating character). Produce terms and reset it.
     string initials;
     if (span_is_initials(initials)) {
@@ -621,16 +622,12 @@ bool TextSplit::text_to_words(const string &in)
     bool nlpending = false;
     bool softhyphenpending = false;
 
-    // Running count of non-alphanum chars. Reset when we see one;
-    int nonalnumcnt = 0;
-
     Utf8Iter it(in);
 #if defined(KATAKANA_AS_WORDS) || defined(HANGUL_AS_WORDS) || defined(CHINESE_AS_WORDS)
     int prev_csc = -1;
 #endif
     for (; !it.eof() && !it.error(); it++) {
         unsigned int c = *it;
-        nonalnumcnt++;
 
         if (c == (unsigned int)-1) {
             LOGERR("Textsplit: error occurred while scanning UTF-8 string\n");
@@ -733,7 +730,6 @@ bool TextSplit::text_to_words(const string &in)
             continue;
 
         case DIGIT:
-            nonalnumcnt = 0;
             if (m_wordLen == 0)
                 m_inNumber = true;
             m_wordLen += it.appendchartostring(m_span);
@@ -741,7 +737,6 @@ bool TextSplit::text_to_words(const string &in)
             break;
 
         case SPACE:
-            nonalnumcnt = 0;
         SPACE:
             if (m_wordLen || m_span.length()) {
                 if (!doemit(true, it.getBpos()))
@@ -989,7 +984,6 @@ bool TextSplit::text_to_words(const string &in)
 
         default:
         NORMALCHAR:
-            nonalnumcnt = 0;
             if (m_inNumber && c != 'e' && c != 'E') {
                 m_inNumber = false;
             }
