@@ -69,11 +69,10 @@ class rclEPUB:
             if item is None or item.media_type != 'application/xhtml+xml':
                 continue
             doc = self.book.read_item(item)
-            doc = re.sub(b'''<\?.*\?>''', b'', doc)
-            doc = re.sub(b'''<html.*<body[^>]*>''',
-                         b'', doc, 1, flags=re.DOTALL|re.I)
-            doc = re.sub(b'''</body>''', b'', doc, flags=re.I)
-            doc = re.sub(b'''</html>''', b'', doc, flags=re.I)
+            doc = re.sub(rb'<\?.*\?>', b'', doc)
+            doc = re.sub(rb'<html.*<body[^>]*>', b'', doc, 1, flags=re.DOTALL|re.I)
+            doc = re.sub(rb'</body>', b'', doc, flags=re.I)
+            doc = re.sub(rb'</html>', b'', doc, flags=re.I)
             data += doc
 
         data += b'</body></html>'
@@ -102,8 +101,8 @@ class rclEPUB:
             if item is None:
                 raise Exception("Item not found for id %s" % (id,))
             doc = self.book.read_item(item)
-            doc = re.sub(b'''</[hH][eE][aA][dD]>''',
-                        b'''<meta name="rclaptg" content="epub"></head>''', doc)
+            doc = re.sub(rb'</[hH][eE][aA][dD]>',
+                         b'<meta name="rclaptg" content="epub"></head>', doc)
             self.em.setmimetype(rclepub_html_mtype)
             return (True, doc, id, iseof)
         except Exception as err:
