@@ -1,19 +1,38 @@
 #!/usr/bin/env python3
-from __future__ import print_function
+# Copyright (C) 2020-2022 J.F.Dockes
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the
+# Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-# Read an org-mode file, break it into "documents" along the separator lines
-# and interface with recoll execm
+'''Read an org-mode file, optionally break it into subdocs" along level 1 headings'''
 
-import rclexecm
 import sys
 import re
 
+import rclexecm
+import rclconfig
+import conftree
+
 class OrgModeExtractor:
     def __init__(self, em):
         self.file = ""
-        self.contents = []
         self.em = em
-
+        self.selftext = ""
+        self.docs = []
+        config = rclconfig.RclConfig()
+        self.createsubdocs = conftree.valToBool(config.getConfParam("orgmodesubdocs"))
+        
     def extractone(self, index):
         if index >= len(self.docs):
             return(False, "", "", True)
@@ -33,7 +52,6 @@ class OrgModeExtractor:
     ###### File type handler api, used by rclexecm ---------->
     def openfile(self, params):
         self.file = params["filename"]
-
         try:
             data = open(self.file, "rb").read()
         except Exception as e:
@@ -41,9 +59,15 @@ class OrgModeExtractor:
             return False
 
         self.currentindex = -1
+        if not self.createsubdocs:
+            self.selftext = data
+            return True
 
-        res = rb'''^\* '''
+        res = rb"^\* "
         self.docs = re.compile(res, flags=re.MULTILINE).split(data)
+        # Note that there can be text before the first heading. This goes into the self doc,
+        # because it's not a proper entry.
+        self.selftext = self.docs[0]
         self.docs = self.docs[1:]
         #self.em.rclog("openfile: Entry count: %d" % len(self.docs))
         return True
@@ -59,6 +83,8 @@ class OrgModeExtractor:
         return self.extractone(index)
         
     def getnext(self, params):
+        if not self.createsubdocs:
+            return (True, self.selftext, "", rclexecm.RclExecM.eofnext)
 
         if self.currentindex == -1:
             # Return "self" doc
@@ -68,7 +94,7 @@ class OrgModeExtractor:
                 eof = rclexecm.RclExecM.eofnext
             else:
                 eof = rclexecm.RclExecM.noteof
-            return (True, "", "", eof)
+            return (True, self.selftext, "", eof)
 
         if self.currentindex >= len(self.docs):
             self.em.rclog("getnext: EOF hit")
