@@ -43,10 +43,12 @@ if _mswindows:
     import platform
     if platform.machine().endswith('64'):
         # See comments in ../windows/mkinstdir.sh about the setup of the poppler installation
-        popplerdir = "poppler/Library/bin"
+        popplerdir = "poppler/Library/bin/"
     else:
-        popplerdir = "poppler32"
-
+        popplerdir = "poppler32/"
+else:
+    popplerdir = ""
+    
 # Test access to the poppler-glib python3 bindings ? This allows
 # extracting text from annotations.
 # - On Ubuntu, this comes with package gir1.2-poppler-0.18
@@ -111,18 +113,22 @@ class PDFExtractor:
         self.tesseract = None
         self.extrameta = None
         self.re_head = None
-
+        # Base Metadata elements names replacements: Recoll treats "Subject" as a "title" element
+        # (based on emails). The PDF "Subject" metadata field is more like an HTML "description".
+        # "Producer" is the name of the software package used to convert to PDF (e.g. "Writer")
+        # "Creator" is the name of the Software used to create the original format (e.g. "MSWord")
+        # There is a lot of confusion in actual docs about these, and in general "creator" is more
+        # likely to be understood as a synonym for author (explicitely the case for dc:creator
+        # actually). So we replace Producer and Creator with PDF-specific names
+        self.metareplace = {b"Creator" : b"PDFCreator", b"Producer" : b"PDFProducer",
+                            b"Subject" : b"Description"}
         self.config = rclconfig.RclConfig()
         self.confdir = self.config.getConfDir()
 
         # Avoid picking up a default version on Windows, we want ours
-        if not _mswindows:
-            self.pdftotext = rclexecm.which("pdftotext")
-        if _mswindows and not self.pdftotext:
-            self.pdftotext = rclexecm.which(popplerdir + "/pdftotext")
+        self.pdftotext = rclexecm.which(popplerdir + "pdftotext")
         if not self.pdftotext:
-            # No need for anything else. openfile() will return an
-            # error at once
+            # No need for anything else. openfile() will return an error at once
             return
         self.pdftotextversion = self._popplerutilversion(self.pdftotext)
         # Check if we need to escape portions of text: old versions of pdftotext output raw
@@ -133,10 +139,7 @@ class PDFExtractor:
             self.needescape = True
 
         # pdfinfo may be used to extract XML metadata and custom PDF properties
-        if not _mswindows:
-            self.pdfinfo = rclexecm.which("pdfinfo")
-        if _mswindows and not self.pdfinfo:
-            self.pdfinfo = rclexecm.which(popplerdir + "/pdfinfo")
+        self.pdfinfo = rclexecm.which(popplerdir + "pdfinfo")
         if self.pdfinfo:
             self.pdfinfoversion = self._popplerutilversion(self.pdfinfo)
             # The user can set a list of meta tags to be extracted from the XMP metadata
@@ -150,16 +153,12 @@ class PDFExtractor:
         # Extracting the outline / bookmarks needs still another poppler command...
         self.dooutline = self.config.getConfParam("pdfoutline")
         if self.dooutline:
-            if not _mswindows:
-                self.pdftohtml = rclexecm.which("pdftohtml")
-            if _mswindows and not self.pdftohtml:
-                self.pdftohtml = rclexecm.which(popplerdir + "/pdftohtml")
+            self.pdftohtml = rclexecm.which(popplerdir + "pdftohtml")
             if not self.pdftohtml:
                 self.dooutline = False
             
-        # Pdftk is optionally used to extract attachments. This takes
-        # a hit on performance even in the absence of any attachments,
-        # so it can be disabled in the configuration.
+        # Pdftk is optionally used to extract attachments. This takes a hit on performance even in
+        # the absence of any attachments, so it can be disabled in the configuration.
         self.attextractdone = False
         self.attachlist = []
         cf_attach = self.config.getConfParam("pdfattach")
@@ -219,12 +218,11 @@ class PDFExtractor:
         if self.extrametafix:
             try:
                 import importlib.util
-                spec = importlib.util.spec_from_file_location(
-                    'pdfextrametafix', self.extrametafix)
+                spec = importlib.util.spec_from_file_location("pdfextrametafix", self.extrametafix)
                 EMF = importlib.util.module_from_spec(spec)
                 spec.loader.exec_module(EMF)
             except Exception as err:
-                self.em.rclog("Import extrametafix failed: %s" % err)
+                self.em.rclog(f"Import extrametafix failed: {err}")
                 EMF = None
                 pass
 
@@ -267,8 +265,7 @@ class PDFExtractor:
         try:
             fields = {}
             output = subprocess.check_output([self.pdfinfo, "-custom", self.filename],
-                                             stderr=subprocess.STDOUT)
-            output = output.decode("utf-8")
+                                             stderr=subprocess.STDOUT, encoding='utf-8')
             for line in output.split("\n"):
                 colon = line.find(":")
                 if colon > 0:
@@ -291,53 +288,58 @@ class PDFExtractor:
         inheader = False
         inbody = False
         didcs = False
-        output = []
+        output = b''
         isempty = True
         fields = {}
         if self.pdfinfoversion > 211000:
             fields = self._customfields()
         for line in input.split(b'\n'):
-            if re.search(b'</head>', line):
+            if line.find(b'</head>') != -1:
                 inheader = False
-            if re.search(b'</pre>', line):
+            if line.find(b'</pre>') != -1:
                 inbody = False
             if inheader:
                 if not didcs:
-                    output.append(b'<meta http-equiv="Content-Type"' + \
-                              b'content="text/html; charset=UTF-8">\n')
+                    output +=b'<meta http-equiv="Content-Type" content="text/html;charset=UTF-8">\n'
                     for fld,val in fields.items():
-                        output.append(self._metatag(fld, val))
+                        output += self._metatag(fld, val) + b"\n"
                     didcs = True
+                m = None
                 if self.needescape:
-                    m = re.search(b'''(.*<title>)(.*)(<\/title>.*)''', line)
-                    if not m:
-                        m = re.search(b'''(.*content=")(.*)(".*/>.*)''', line)
+                    # Look for a title line and escape the data
+                    m = re.search(rb'(.*<title>)(.*)(<\/title>.*)', line)
                     if m:
-                        line = m.group(1) + rclexecm.htmlescape(m.group(2)) + \
-                               m.group(3)
-
-                # Recoll treats "Subject" as a "title" element
-                # (based on emails). The PDF "Subject" metadata
-                # field is more like an HTML "description"
-                line = re.sub(b'name="Subject"', b'name="Description"', line, 1)
+                        line = m.group(1) + rclexecm.htmlescape(m.group(2)) + m.group(3)
+                if not m:
+                    # Not a title line. Look for a meta one, possibly replace the name and escape
+                    # the data if needed
+                    m = re.search(rb'(.*name=")([^"]*)(.*content=")(.*)(".*/>.*)', line)
+                    if m:
+                        nm = m.group(2)
+                        data = m.group(4)
+                        if self.needescape:
+                            data = rclexecm.htmlescape(data)
+                        if nm in self.metareplace:
+                            nm = self.metareplace[nm]
+                        line = b'<meta name="' +  nm + b'" content="' + data + b'"/>'
 
             elif inbody:
                 s = line[0:1]
                 if s != b"\x0c" and s != b"<":
                     isempty = False
-                # We used to remove end-of-line hyphenation (and join
-                # lines), but but it's not clear that we should do
-                # this as pdftotext without the -layout option does it ?
+                # We used to remove end-of-line hyphenation (and join lines), but but it's not clear
+                # that we should do this as pdftotext without the -layout option does it ?
+                # pdftotext -htmlmeta v 22.02.0 2024-02 *still* does not escape the body text !
                 line = rclexecm.htmlescape(line)
 
-            if re.search(b'<head>', line):
+            if line.find(b'<head>') != -1:
                 inheader = True
-            if re.search(b'<pre>', line):
+            if line.find(b'<pre>') != -1:
                 inbody = True
 
-            output.append(line)
+            output += line + b"\n"
 
-        return b'\n'.join(output), isempty
+        return output, isempty
 
 
     def _metatag(self, nm, val):
@@ -472,7 +474,7 @@ class PDFExtractor:
         else:
             tmpdir = rclexecm.SafeTmpDir("rclpdf", self.em)
             #self.em.rclog("Using temporary directory %s" % tmpdir.getpath())
-            if self.pdftk and re.match("/snap/", self.pdftk):
+            if self.pdftk and re.match(r"/snap/", self.pdftk):
                 # We know this is Unix (Ubuntu actually). Check that tmpdir
                 # belongs to the user as snap commands can't use /tmp to share
                 # files. Don't generate an error as this only affects
