@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (C) 2014 J.F.Dockes
+# Copyright (C) 2014-2024 J.F.Dockes
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
@@ -20,14 +20,12 @@
 
 import os
 import posixpath
-import fnmatch
 import datetime
 
 from zipfile import ZipFile
 
 import rclexecm
-import rclconfig
-import conftree
+from archivextract import ArchiveExtractor
 
 # Note about file names (python 2.6. 2.7, don't know about 3.)
 #
@@ -68,14 +66,13 @@ import conftree
 # occurs in process.c:GetUnicodeData(), which succeeds in finding an
 # utf-8 string which zipfile does not see (to be checked: was a quick look). 
 # Anyway: this is a python zipfile issue.
-class ZipExtractor:
+class ZipExtractor(ArchiveExtractor):
     def __init__(self, em):
         self.filename = None
         self.f = None
         self.zip = None
-        self.currentindex = 0
-        self.em = em
-
+        super().__init__(em)
+        
     def closefile(self):
         #self.em.rclog("Closing %s" % self.filename)
         if self.zip:
@@ -125,18 +122,7 @@ class ZipExtractor:
         filename = params["filename"]
         self.filename = filename
         self.currentindex = -1
-        self.skiplist = []
-
-        config = rclconfig.RclConfig()
-        config.setKeyDir(os.path.dirname(filename))
-        usebaseskipped = config.getConfParam("zipUseSkippedNames")
-        if usebaseskipped:
-            skipped = config.getConfParam("skippedNames")
-            self.em.rclog("skippedNames: %s"%self.skiplist)
-            self.skiplist += conftree.stringToStrings(skipped)
-        skipped = config.getConfParam("zipSkippedNames")
-        if skipped is not None:
-            self.skiplist += conftree.stringToStrings(skipped)
+        self.namefilter.setforlocation(filename)
         try:
             # Note: py3 ZipFile wants an str file name, which
             # is wrong: file names are binary. But it accepts an
@@ -148,59 +134,12 @@ class ZipExtractor:
             self.em.rclog("openfile: failed: [%s]" % err)
             return False
 
-    def getipath(self, params):
-        ipath = params["ipath"]
-        ok, data, ipath, eof = self.extractone(ipath)
-        if ok:
-            return (ok, data, ipath, eof)
-        # Not found. Maybe we need to decode the path?
-        try:
-            ipath = ipath.decode("utf-8")
-            return self.extractone(ipath)
-        except Exception as err:
-            self.em.rclog("extractone: failed: [%s]" % err)
-            return (ok, data, ipath, eof)
-        
-    def getnext(self, params):
-        if self.currentindex == -1:
-            # Return "self" doc
-            self.currentindex = 0
-            self.em.setmimetype('text/plain')
-            if len(self.zip.namelist()) == 0:
-                self.closefile()
-                eof = rclexecm.RclExecM.eofnext
-            else:
-                eof = rclexecm.RclExecM.noteof
-            return (True, "", "", eof)
-
-        if self.currentindex >= len(self.zip.namelist()):
-            #self.em.rclog("getnext: EOF hit")
-            self.closefile()
-            return (False, "", "", rclexecm.RclExecM.eofnow)
-        else:
-            entryname = self.zip.namelist()[self.currentindex]
-            # This is how we'd fix a badly decoded entry, but then
-            # this can't be used as ipath any more
-            #fixedname = entryname.encode('cp437').decode('euc-kr')
-            #self.em.rclog("REENCODED: %s"%fixedname)
-
-            if len(self.skiplist) != 0:
-                while self.currentindex < len(self.zip.namelist()):
-                    entryname = self.zip.namelist()[self.currentindex]
-                    for pat in self.skiplist:
-                        if fnmatch.fnmatch(entryname, pat):
-                            entryname = None
-                            break
-                    if entryname is not None:
-                        break
-                    self.currentindex += 1
-                if entryname is None:
-                    self.closefile()
-                    return (False, "", "", rclexecm.RclExecM.eofnow)
-                
-            ret= self.extractone(entryname)
-            self.currentindex += 1
-            return ret
+    def namelist(self):
+        return self.zip.namelist()
+    
+    # getipath from ArchiveExtractor
+    # getnext inherited from ArchiveExtractor
+    
 
 # Main program: create protocol handler and extractor and run them
 proto = rclexecm.RclExecM()
