@@ -26,7 +26,7 @@
 #else
 #include <direct.h>
 #endif
-#include "safefcntl.h"
+#include <fcntl.h>
 #include "safeunistd.h"
 #include <getopt.h>
 
@@ -90,6 +90,7 @@ static int     op_flags;
 #define OPT_x 0x400000
 #define OPT_Z 0x800000
 #define OPT_z 0x1000000
+#define OPT_O 0x2000000
 
 #define OPTVAL_WEBCACHE_COMPACT 1000
 #define OPTVAL_WEBCACHE_BURST 1001
@@ -199,15 +200,21 @@ static void setMyPriority(const RclConfig *config)
 {
     PRETEND_USE(config);
 #ifndef _WIN32
-    int prio{19};
-    std::string sprio;
-    config->getConfParam("idxniceprio", sprio);
-    if (!sprio.empty()) {
-        prio = atoi(sprio.c_str());
-    }
+    // Note: will be clamped to 19 on Linux. Allows the user to set idxniceprio to 19 to avoid
+    // SCHED_IDLE use (see below).
+    int prio{20};
+    config->getConfParam("idxniceprio", &prio);
     if (setpriority(PRIO_PROCESS, 0, prio) != 0) {
-        LOGINFO("recollindex: can't setpriority(), errno " << errno << "\n");
+        LOGSYSERR("recollindex", "setpriority", std::to_string(prio));
     }
+#ifdef SCHED_IDLE
+    // By default, or if the user has set idxniceprio > 19, use SCHED_IDLE if available.
+    if (prio > 19) {
+        struct sched_param param;
+        memset(&param, 0, sizeof(param));
+        sched_setscheduler(getpid(), SCHED_IDLE, &param);
+    }
+#endif
     // Try to ionice. This does not work on all platforms
     rclIxIonice(config);
 #endif
@@ -396,13 +403,15 @@ static const char usage [] =
 "    --diagsfile <outputpath> : list skipped or otherwise not indexed documents to <outputpath>\n"
 "       <outputpath> will be truncated\n"
 #ifdef RCL_MONITOR
-"recollindex -m [-w <secs>] -x [-D] [-C]\n"
-"    Perform real time indexing. Don't become a daemon if -D is set.\n"
-"    -w sets number of seconds to wait before starting.\n"
-"    -C disables monitoring config for changes/reexecuting.\n"
-"    -n disables initial incremental indexing (!and purge!).\n"
+"recollindex -m [-w <secs>] -x [-D | -O] [-C] \n"
+"    Perform real-time indexing.\n"
+"    -D  : Don't become a daemon (keep running in the foreground).\n"
+"    -O  : Like -D but in addition quit when the parent process exits (i.e., if this process becomes orphaned).\n"
+"    -w  : Set the number of seconds to wait before starting.\n"
+"    -C  : Disable monitoring of config changes and re-executing.\n"
+"    -n  : Disable initial incremental indexing (!and purge!).\n"
 #ifndef DISABLE_X11MON
-"    -x disables exit on end of x11 session\n"
+"    -x  : Disable exit on end of X11 session.\n"
 #endif /* DISABLE_X11MON */
 #endif /* RCL_MONITOR */
 "recollindex -e [<filepath [path ...]>]\n"
@@ -578,13 +587,14 @@ int main(int argc, char *argv[])
     
     std::string burstdir;
     std::string diagsfile;
-    while ((ret = getopt_long(argc, (char *const*)&args[0], "c:CDdEefhikKlmnPp:rR:sSw:xZz",
+    while ((ret = getopt_long(argc, (char *const*)&args[0], "c:CDOdEefhikKlmnPp:rR:sSw:xZz",
                               long_options, NULL)) != -1) {
         switch (ret) {
         case 'c':  op_flags |= OPT_c; a_config = optarg; break;
 #ifdef RCL_MONITOR
         case 'C': op_flags |= OPT_C; break;
         case 'D': op_flags |= OPT_D; break;
+        case 'O': op_flags |= OPT_O; break;
 #endif
 #if defined(HAVE_POSIX_FADVISE)
         case 'd': op_flags |= OPT_d; break;
@@ -643,6 +653,11 @@ int main(int argc, char *argv[])
         Usage();
     }
 
+    // if -O is provided, internally -D is also enabled
+    if(op_flags & OPT_O) {
+        op_flags |= OPT_D;
+    }
+
     string reason;
     int flags = RCLINIT_IDX;
     if ((op_flags & OPT_m) && !(op_flags & OPT_D)) {
@@ -881,8 +896,8 @@ int main(int argc, char *argv[])
         if (sleepsecs > 0) {
             LOGDEB("recollindex: sleeping " << sleepsecs << "\n");
             for (int i = 0; i < sleepsecs; i++) {
-                sleep(1);
-#ifndef _WIN32
+                millisleep(1000);
+#ifndef DISABLE_X11MON
                 // Check that x11 did not go away while we were sleeping.
                 if (!(op_flags & OPT_x) && !x11IsAlive()) {
                     LOGDEB("X11 session went away during initial sleep period\n");
@@ -922,6 +937,8 @@ int main(int argc, char *argv[])
         int opts = RCLMON_NONE;
         if (op_flags & OPT_D)
             opts |= RCLMON_NOFORK;
+        if (op_flags & OPT_O)
+            opts |= RCLMON_NOORPHAN;
         if (op_flags & OPT_C)
             opts |= RCLMON_NOCONFCHECK;
         if (op_flags & OPT_x)
