@@ -42,22 +42,28 @@
 
 using namespace std;
 
-#ifdef _WIN32
-#define strcasecmp _stricmp
-#endif /* _WIN32 */
-
 #if PY_MAJOR_VERSION >=3
 #  define Py_TPFLAGS_HAVE_ITER 0
 #else
 #define PyLong_FromLong PyInt_FromLong 
 #endif
 
-// To keep old code going after we moved the static rclconfig to the
-// db object (to fix multiple dbs issues), we keep a copy of the last
-// created rclconfig in RCLCONFIG. This is set into the doc objec by
-// doc_init, then reset to the db's by db::doc() or query::iter_next,
-// the proper Doc creators.
-static shared_ptr<RclConfig> RCLCONFIG;
+static std::string stringfromobject(PyObject *pyobj)
+{
+    std::string out;
+    if (PyUnicode_Check(pyobj)) {
+        Py_ssize_t sz;
+        const char *bytes = PyUnicode_AsUTF8AndSize(pyobj, &sz);
+        out = std::string(bytes, sz);
+    } else {
+        if (!PyBytes_Check(pyobj)) {
+            PyErr_SetString(PyExc_AttributeError, "Input must be str or bytes");
+            return 0;
+        }
+        out = std::string(PyBytes_AsString(pyobj), PyBytes_Size(pyobj));
+    }
+    return out;
+}
 
 //////////////////////////////////////////////////////////////////////
 /// SEARCHDATA SearchData code
@@ -76,18 +82,6 @@ SearchData_dealloc(recoll_SearchDataObject *self)
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
-static PyObject *
-SearchData_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
-{
-    LOGDEB("SearchData_new\n");
-    recoll_SearchDataObject *self;
-
-    self = (recoll_SearchDataObject *)type->tp_alloc(type, 0);
-    if (self == 0) 
-        return 0;
-    return (PyObject *)self;
-}
-
 PyDoc_STRVAR(doc_SearchDataObject,
              "SearchData([type=AND|OR], [stemlang=somelanguage|null])\n"
              "\n"
@@ -138,50 +132,20 @@ SearchData_addclause(recoll_SearchDataObject* self, PyObject *args,
                      PyObject *kwargs);
 
 static PyMethodDef SearchData_methods[] = {
-    {"addclause", (PyCFunction)SearchData_addclause, METH_VARARGS|METH_KEYWORDS,
-     doc_addclause},
+    {"addclause", (PyCFunction)SearchData_addclause, METH_VARARGS|METH_KEYWORDS, doc_addclause},
     {NULL}  /* Sentinel */
 };
 
 static PyTypeObject recoll_SearchDataType = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    "_recoll.SearchData",             /*tp_name*/
-    sizeof(recoll_SearchDataObject), /*tp_basicsize*/
-    0,                         /*tp_itemsize*/
-    (destructor)SearchData_dealloc,    /*tp_dealloc*/
-    0,                         /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
-    0,                         /*tp_repr*/
-    0,                         /*tp_as_number*/
-    0,                         /*tp_as_sequence*/
-    0,                         /*tp_as_mapping*/
-    0,                         /*tp_hash */
-    0,                         /*tp_call*/
-    0,                         /*tp_str*/
-    0,                         /*tp_getattro*/
-    0,                         /*tp_setattro*/
-    0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,  /*tp_flags*/
-    doc_SearchDataObject,      /* tp_doc */
-    0,                       /* tp_traverse */
-    0,                       /* tp_clear */
-    0,                       /* tp_richcompare */
-    0,                       /* tp_weaklistoffset */
-    0,                       /* tp_iter */
-    0,                       /* tp_iternext */
-    SearchData_methods,        /* tp_methods */
-    0,                         /* tp_members */
-    0,                         /* tp_getset */
-    0,                         /* tp_base */
-    0,                         /* tp_dict */
-    0,                         /* tp_descr_get */
-    0,                         /* tp_descr_set */
-    0,                         /* tp_dictoffset */
-    (initproc)SearchData_init, /* tp_init */
-    0,                         /* tp_alloc */
-    SearchData_new,            /* tp_new */
+    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name = "_recoll.SearchData",
+    .tp_basicsize = sizeof(recoll_SearchDataObject),
+    .tp_dealloc = (destructor)SearchData_dealloc,
+    .tp_flags = Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,
+    .tp_doc = doc_SearchDataObject,
+    .tp_methods = SearchData_methods,
+    .tp_init = (initproc)SearchData_init,
+    .tp_new = PyType_GenericNew,
 };
 
 static PyObject *
@@ -300,33 +264,16 @@ SearchData_addclause(recoll_SearchDataObject* self, PyObject *args,
 static void 
 Doc_dealloc(recoll_DocObject *self)
 {
-    LOGDEB("Doc_dealloc\n");
+    LOGDEB0("Doc_dealloc\n");
     deleteZ(self->doc);
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
-static PyObject *
-Doc_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
-{
-    LOGDEB("Doc_new\n");
-    recoll_DocObject *self;
-
-    self = (recoll_DocObject *)type->tp_alloc(type, 0);
-    if (self == 0) 
-        return 0;
-    self->doc = 0;
-    return (PyObject *)self;
-}
-
 static int
 Doc_init(recoll_DocObject *self, PyObject *, PyObject *)
 {
-    LOGDEB("Doc_init\n");
-    delete self->doc;
+    LOGDEB0("Doc_init\n");
     self->doc = new Rcl::Doc;
-    if (self->doc == 0)
-        return -1;
-    self->rclconfig = RCLCONFIG;
     return 0;
 }
 
@@ -346,8 +293,7 @@ Doc_getbinurl(recoll_DocObject *self)
         PyErr_SetString(PyExc_AttributeError, "doc is NULL");
         Py_RETURN_NONE;
     }
-    return PyBytes_FromStringAndSize(self->doc->url.c_str(), 
-                                            self->doc->url.size());
+    return PyBytes_FromStringAndSize(self->doc->url.c_str(), self->doc->url.size());
 }
 
 PyDoc_STRVAR(
@@ -365,6 +311,10 @@ Doc_setbinurl(recoll_DocObject *self, PyObject *value)
         PyErr_SetString(PyExc_AttributeError, "doc??");
         return 0;
     }
+    if (!self->rclconfig || !self->rclconfig->ok()) {
+        PyErr_SetString(PyExc_AttributeError, "Configuration not initialized");
+        return 0;
+    }
     if (PyByteArray_Check(value)) {
         self->doc->url = string(PyByteArray_AsString(value), PyByteArray_Size(value));
     } else if (PyBytes_Check(value)) {
@@ -374,7 +324,7 @@ Doc_setbinurl(recoll_DocObject *self, PyObject *value)
         return 0;
     }        
 
-    printableUrl(self->rclconfig->getDefCharset(), self->doc->url, self->doc->meta[Rcl::Doc::keyurl]);
+    printableUrl(self->rclconfig->getDefCharset(),self->doc->url, self->doc->meta[Rcl::Doc::keyurl]);
     Py_RETURN_NONE;
 }
 
@@ -774,44 +724,19 @@ PyDoc_STRVAR(
     );
 
 PyTypeObject recoll_DocType = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    "_recoll.Doc",             /*tp_name*/
-    sizeof(recoll_DocObject), /*tp_basicsize*/
-    0,                         /*tp_itemsize*/
-    (destructor)Doc_dealloc,    /*tp_dealloc*/
-    0,                         /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,  /*tp_setattr*/
-    0,                         /*tp_compare*/
-    0,                         /*tp_repr*/
-    0,                         /*tp_as_number*/
-    0,                         /*tp_as_sequence*/
-    &doc_as_mapping,          /*tp_as_mapping */
-    0,                         /*tp_hash */
-    0,                         /*tp_call*/
-    0,                         /*tp_str*/
-    (getattrofunc)Doc_getattro,/*tp_getattro*/
-    (setattrofunc)Doc_setattro,/*tp_setattro*/
-    0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT,        /*tp_flags*/
-    doc_DocObject,             /* tp_doc */
-    0,                       /* tp_traverse */
-    0,                       /* tp_clear */
-    0,                       /* tp_richcompare */
-    0,                       /* tp_weaklistoffset */
-    0,                       /* tp_iter */
-    0,                       /* tp_iternext */
-    Doc_methods,               /* tp_methods */
-    0,                         /* tp_members */
-    0,                         /* tp_getset */
-    0,                         /* tp_base */
-    0,                         /* tp_dict */
-    0,                         /* tp_descr_get */
-    0,                         /* tp_descr_set */
-    0,                         /* tp_dictoffset */
-    (initproc)Doc_init,        /* tp_init */
-    0,                         /* tp_alloc */
-    Doc_new,                   /* tp_new */
+    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name = "_recoll.Doc",
+    .tp_basicsize = sizeof(recoll_DocObject),
+    .tp_itemsize = 0,
+    .tp_dealloc = (destructor)Doc_dealloc,
+    .tp_as_mapping = &doc_as_mapping,
+    .tp_getattro = (getattrofunc)Doc_getattro,
+    .tp_setattro = (setattrofunc)Doc_setattro,
+    .tp_flags = Py_TPFLAGS_DEFAULT,
+    .tp_doc = doc_DocObject,
+    .tp_methods = Doc_methods,
+    .tp_init = (initproc)Doc_init,
+    .tp_new = PyType_GenericNew,
 };
 
 
@@ -852,15 +777,12 @@ Query_dealloc(recoll_QueryObject *self)
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
-static PyObject *
-Query_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
+// Query_init creates an unusable object. The only way to create a valid Query Object is through
+// db_query(). (or we'd need to add a Db parameter to the Query object creation method)
+static int
+Query_init(recoll_QueryObject *self, PyObject *, PyObject *)
 {
-    LOGDEB("Query_new\n");
-    recoll_QueryObject *self;
-
-    self = (recoll_QueryObject *)type->tp_alloc(type, 0);
-    if (self == 0) 
-        return 0;
+    LOGDEB0("Query_init\n");
     self->query = 0;
     self->next = -1;
     self->rowcount = -1;
@@ -869,21 +791,6 @@ Query_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
     self->arraysize = 1;
     self->connection = 0;
     self->fetchtext = false;
-    return (PyObject *)self;
-}
-
-// Query_init creates an unusable object. The only way to create a
-// valid Query Object is through db_query(). (or we'd need to add a Db
-// parameter to the Query object creation method)
-static int
-Query_init(recoll_QueryObject *self, PyObject *, PyObject *)
-{
-    LOGDEB("Query_init\n");
-
-    delete self->query;
-    self->query = 0;
-    self->next = -1;
-    self->ascending = true;
     return 0;
 }
 
@@ -982,12 +889,12 @@ Query_execute(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
     } else {
         self->query->setCollapseDuplicates(false);
     }
-        
-    // SearchData defaults to stemming in english
-    // Use default for now but need to add way to specify language
+
+    // The searchdata does not keep a ref to the rclconfig, it's just used during the call. So ok to
+    // use the raw pointer.
     string reason;
     std::shared_ptr<Rcl::SearchData> rq = wasaStringToRcl(
-        self->connection->rclconfig.get(),dostem ? stemlang : "", utf8, reason);
+        self->connection->rclconfig.get(), dostem ? stemlang : "", utf8, reason);
 
     if (!rq) {
         PyErr_SetString(PyExc_ValueError, reason.c_str());
@@ -1045,12 +952,11 @@ Query_executesd(recoll_QueryObject* self, PyObject *args, PyObject *kwargs)
     return Py_BuildValue("i", cnt);
 }
 
-// Move some data from the dedicated fields to the meta array to make
-// fetching attributes easier. Needed because we only use the meta
-// array when enumerating keys. Also for url which is also formatted.
-// But note that some fields are not copied, and are only reachable if
-// one knows their name (e.g. xdocid).
-static void movedocfields(const RclConfig* rclconfig, Rcl::Doc *doc)
+// Move some data from the dedicated fields to the meta array to make fetching attributes
+// easier. Needed because we only use the meta array when enumerating keys. Also for url which is
+// also formatted.  But note that some fields are not copied, and are only reachable (through
+// doc_Get, as doc[fldname]) if one knows their name (e.g. xdocid).
+static void movedocfields(std::shared_ptr<RclConfig> rclconfig, Rcl::Doc *doc)
 {
     printableUrl(rclconfig->getDefCharset(), doc->url, doc->meta[Rcl::Doc::keyurl]);
     doc->meta[Rcl::Doc::keytp] = doc->mimetype;
@@ -1081,15 +987,14 @@ Query_iternext(PyObject *_self)
         return 0;
     }
     result->rclconfig = self->connection->rclconfig;
-    // We used to check against rowcount here, but this was wrong:
-    // xapian result count estimate are sometimes wrong, we must go on
-    // fetching until we fail
+    // We used to check against rowcount here, but this was wrong: xapian result count estimate are
+    // sometimes wrong, we must go on fetching until we fail
     if (!self->query->getDoc(self->next, *result->doc, self->fetchtext)) {
         return 0;
     }
     self->next++;
 
-    movedocfields(self->connection->rclconfig.get(), result->doc);
+    movedocfields(self->connection->rclconfig, result->doc);
     return (PyObject *)result;
 }
 
@@ -1557,45 +1462,20 @@ PyDoc_STRVAR(doc_QueryObject,
              "Recoll Query objects are used to execute index searches. \n"
              "They must be created by the Db.query() method.\n"
     );
+
 PyTypeObject recoll_QueryType = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    "_recoll.Query",             /*tp_name*/
-    sizeof(recoll_QueryObject), /*tp_basicsize*/
-    0,                         /*tp_itemsize*/
-    (destructor)Query_dealloc, /*tp_dealloc*/
-    0,                         /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
-    0,                         /*tp_repr*/
-    0,                         /*tp_as_number*/
-    0,                         /*tp_as_sequence*/
-    0,                         /*tp_as_mapping*/
-    0,                         /*tp_hash */
-    0,                         /*tp_call*/
-    0,                         /*tp_str*/
-    0,                         /*tp_getattro*/
-    0,                         /*tp_setattro*/
-    0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_ITER, /*tp_flags*/
-    doc_QueryObject,           /* tp_doc */
-    0,                       /* tp_traverse */
-    0,                       /* tp_clear */
-    0,                       /* tp_richcompare */
-    0,                       /* tp_weaklistoffset */
-    Query_iter,                   /* tp_iter */
-    Query_iternext,            /* tp_iternext */
-    Query_methods,             /* tp_methods */
-    Query_members,             /* tp_members */
-    0,                         /* tp_getset */
-    0,                         /* tp_base */
-    0,                         /* tp_dict */
-    0,                         /* tp_descr_get */
-    0,                         /* tp_descr_set */
-    0,                         /* tp_dictoffset */
-    (initproc)Query_init,      /* tp_init */
-    0,                         /* tp_alloc */
-    Query_new,                 /* tp_new */
+    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name = "_recoll.Query",
+    .tp_basicsize = sizeof(recoll_QueryObject),
+    .tp_dealloc = (destructor)Query_dealloc,
+    .tp_flags = Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_ITER,
+    .tp_doc = doc_QueryObject,
+    .tp_iter = Query_iter,
+    .tp_iternext = Query_iternext,
+    .tp_methods = Query_methods,
+    .tp_members = Query_members,
+    .tp_init = (initproc)Query_init,
+    .tp_new = PyType_GenericNew,
 };
 
 
@@ -1606,10 +1486,8 @@ static PyObject *
 Db_close(recoll_DbObject *self)
 {
     LOGDEB("Db_close. self " << self << "\n");
-    if (self->db) {
-        delete self->db;
-        self->db = 0;
-    }
+    delete self->db;
+    self->db = 0;
     self->rclconfig.reset();
     Py_RETURN_NONE;
 }
@@ -1623,19 +1501,6 @@ Db_dealloc(recoll_DbObject *self)
     Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
-static PyObject *
-Db_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
-{
-    LOGDEB2("Db_new\n");
-    recoll_DbObject *self;
-
-    self = (recoll_DbObject *)type->tp_alloc(type, 0);
-    if (self == 0) 
-        return 0;
-    self->db = 0;
-    return (PyObject *)self;
-}
-
 static int
 Db_init(recoll_DbObject *self, PyObject *args, PyObject *kwargs)
 {
@@ -1654,13 +1519,10 @@ Db_init(recoll_DbObject *self, PyObject *args, PyObject *kwargs)
     string reason;
     if (confdir) {
         string cfd = confdir;
-        self->rclconfig = std::shared_ptr<RclConfig>(
-            recollinit(RCLINIT_PYTHON, 0, 0, reason, &cfd));
+        self->rclconfig = std::shared_ptr<RclConfig>(recollinit(RCLINIT_PYTHON,0,0, reason, &cfd));
     } else {
-        self->rclconfig = std::shared_ptr<RclConfig>(
-            recollinit(RCLINIT_PYTHON, 0, 0, reason, 0));
+        self->rclconfig = std::shared_ptr<RclConfig>(recollinit(RCLINIT_PYTHON, 0, 0, reason, 0));
     }
-    RCLCONFIG = self->rclconfig;
     LOGDEB("Db_init\n");
 
     if (!self->rclconfig) {
@@ -1684,7 +1546,7 @@ Db_init(recoll_DbObject *self, PyObject *args, PyObject *kwargs)
         return -1;
     }
 
-    if (extradbs) {
+    if (extradbs && extradbs != Py_None) {
         if (!PySequence_Check(extradbs)) {
             PyErr_SetString(PyExc_TypeError, "extra_dbs must be a sequence");
             deleteZ(self->db);
@@ -1761,7 +1623,6 @@ Db_doc(recoll_DbObject* self)
     if (!result)
         return 0;
     result->rclconfig = self->rclconfig;
-    Py_INCREF(self);
 
     return (PyObject *)result;
 }
@@ -1769,19 +1630,19 @@ Db_doc(recoll_DbObject* self)
 static PyObject *
 Db_getDoc(recoll_DbObject* self, PyObject *args, PyObject *kwargs)
 {
-    LOGDEB("Db_doc\n");
+    LOGDEB("Db_getDoc\n");
     if (self->db == 0) {
-        LOGERR("Db_doc: db not found " << self->db << "\n");
+        LOGERR("Db_getDoc: db not found " << self->db << "\n");
         PyErr_SetString(PyExc_AttributeError, "db");
         return 0;
     }
     int idxidx = 0;
-    char *cudi = 0;
+    PyObject *pyudi = 0;
     static const char *kwlist[] = {"idxidx", NULL};
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s|i", (char**)kwlist, &cudi, &idxidx)) {
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O|i", (char**)kwlist, &pyudi, &idxidx)) {
         return 0;
     }
-    std::string udi(cudi);
+    std::string udi = stringfromobject(pyudi);
 
     recoll_DocObject *pydoc =
         (recoll_DocObject *)PyObject_CallObject((PyObject *)&recoll_DocType, 0);
@@ -1792,7 +1653,6 @@ Db_getDoc(recoll_DbObject* self, PyObject *args, PyObject *kwargs)
         PyErr_SetString(PyExc_AttributeError, "Doc not found: bad UDI or idx index");
         return 0;
     }
-    Py_INCREF(self);
     return (PyObject *)pydoc;
 }
 
@@ -1938,6 +1798,28 @@ out:
     return ret;
 }
 
+static PyObject *
+Db_setSynonymsFile(recoll_DbObject *self, PyObject *args)
+{
+    if (self->db == 0) {
+        LOGERR("Db_setSynonymsFile: db not found " << self->db << "\n");
+        PyErr_SetString(PyExc_AttributeError, "db");
+        return 0;
+    }
+    PyBytesObject *py_path = NULL;
+    char *c_path;
+    Py_ssize_t path_size;
+    if (!PyArg_ParseTuple(args, "O&", PyUnicode_FSConverter, &py_path) || py_path == NULL)
+        return 0;
+    PyBytes_AsStringAndSize((PyObject *)py_path, &c_path, &path_size);
+    if (!self->db->setSynGroupsFile(c_path)) {
+        LOGERR("Db_setSynonymsFile: setSynGroupsFile failed\n");
+        PyErr_SetString(PyExc_AttributeError, "setSynGroupsFile failed");
+        return 0;
+    }
+    Py_RETURN_NONE;
+}
+
 static PyObject *
 Db_needUpdate(recoll_DbObject* self, PyObject *args, PyObject *kwds)
 {
@@ -2064,21 +1946,17 @@ static PyObject *
 Db_addOrUpdate(recoll_DbObject* self, PyObject *args, PyObject *kwargs)
 {
     LOGDEB0("Db_addOrUpdate\n");
-    static const char *kwlist[] = {"udi", "doc", "parent_udi", NULL};
-    char *sudi = 0; // needs freeing
-    char *sparent_udi = 0; // needs freeing
+    static const char *kwlist[] = {"udi", "doc", "parent_udi", "metaonly", NULL};
+    PyObject *pyudi = nullptr;
+    PyObject *pyparent_udi = nullptr;
     recoll_DocObject *pydoc;
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "esO!|es:Db_addOrUpdate",
-                                     (char **)kwlist,
-                                     "utf-8", &sudi, &recoll_DocType, &pydoc,
-                                     "utf-8", &sparent_udi)) {
+    int metaonly = 0;
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "OO!|Op:Db_addOrUpdate", (char **)kwlist,
+                                     &pyudi, &recoll_DocType, &pydoc,  &pyparent_udi, &metaonly)) {
         return 0;
     }
-    string udi(sudi);
-    string parent_udi(sparent_udi ? sparent_udi : "");
-    PyMem_Free(sudi);
-    PyMem_Free(sparent_udi);
+    string udi = stringfromobject(pyudi);
+    string parent_udi = pyparent_udi ? stringfromobject(pyparent_udi) : std::string();
 
     if (self->db == 0) {
         LOGERR("Db_addOrUpdate: db not found " << self->db << "\n");
@@ -2090,6 +1968,9 @@ Db_addOrUpdate(recoll_DbObject* self, PyObject *args, PyObject *kwargs)
         PyErr_SetString(PyExc_AttributeError, "doc");
         return 0;
     }
+    if (metaonly) {
+        pydoc->doc->metaonly = 1;
+    }
     if (!self->db->addOrUpdate(udi, parent_udi, *pydoc->doc)) {
         LOGERR("Db_addOrUpdate: rcldb error\n");
         PyErr_SetString(PyExc_AttributeError, "rcldb error");
@@ -2124,8 +2005,10 @@ static PyMethodDef Db_methods[] = {
      "Build and return 'keyword-in-context' abstract for document\n"
      "and query."
     },
-    {"termMatch", (PyCFunction)Db_termMatch, METH_VARARGS|METH_KEYWORDS,
-     doc_Db_termMatch
+    {"termMatch", (PyCFunction)Db_termMatch, METH_VARARGS|METH_KEYWORDS, doc_Db_termMatch},
+    {"setSynonymsFile", (PyCFunction)Db_setSynonymsFile, METH_VARARGS,
+     "setSynonymsFile(path)\n"
+     " Set the synonyms file used when querying."
     },
     {"needUpdate", (PyCFunction)Db_needUpdate, METH_VARARGS,
      "needUpdate(udi, sig) -> Bool.\n"
@@ -2178,45 +2061,17 @@ PyDoc_STRVAR(doc_DbObject,
              "extra_dbs is a list of external databases (xapian directories)\n"
              "writable decides if we can index new data through this connection\n"
     );
+
 static PyTypeObject recoll_DbType = {
-    PyVarObject_HEAD_INIT(NULL, 0)
-    "_recoll.Db",             /*tp_name*/
-    sizeof(recoll_DbObject), /*tp_basicsize*/
-    0,                         /*tp_itemsize*/
-    (destructor)Db_dealloc,    /*tp_dealloc*/
-    0,                         /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
-    0,                         /*tp_repr*/
-    0,                         /*tp_as_number*/
-    0,                         /*tp_as_sequence*/
-    0,                         /*tp_as_mapping*/
-    0,                         /*tp_hash */
-    0,                         /*tp_call*/
-    0,                         /*tp_str*/
-    0,                         /*tp_getattro*/
-    0,                         /*tp_setattro*/
-    0,                         /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,        /*tp_flags*/
-    doc_DbObject,              /* tp_doc */
-    0,                       /* tp_traverse */
-    0,                       /* tp_clear */
-    0,                       /* tp_richcompare */
-    0,                       /* tp_weaklistoffset */
-    0,                       /* tp_iter */
-    0,                       /* tp_iternext */
-    Db_methods,                /* tp_methods */
-    0,                         /* tp_members */
-    0,                         /* tp_getset */
-    0,                         /* tp_base */
-    0,                         /* tp_dict */
-    0,                         /* tp_descr_get */
-    0,                         /* tp_descr_set */
-    0,                         /* tp_dictoffset */
-    (initproc)Db_init,         /* tp_init */
-    0,                         /* tp_alloc */
-    Db_new,                    /* tp_new */
+    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
+    .tp_name = "_recoll.Db",
+    .tp_basicsize = sizeof(recoll_DbObject),
+    .tp_dealloc = (destructor)Db_dealloc,
+    .tp_flags = Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,
+    .tp_doc = doc_DbObject,
+    .tp_methods = Db_methods,
+    .tp_init = (initproc)Db_init,
+    .tp_new = PyType_GenericNew,
 };
 
 
