@@ -13,10 +13,15 @@ QMAKE=${QMAKE:-qmake}
 MAKE=${MAKE:-make}
 
 ncpus=2
-if test -f /proc/cpuinfo; then
-    ncpus=`grep -E '^processor[ 	]*:' /proc/cpuinfo | wc -l`
-elif which sysctl > /dev/null;then
-    ncpus=`sysctl hw.ncpu | awk '{print $3}'`
+if which nproc > /dev/null ; then
+    ncpus=`nproc`
+elif which sysctl > /dev/null ; then
+    ncpus=`sysctl hw.ncpu | awk '{print $2}'`
+elif test -f /proc/cpuinfo ; then
+    ncpus=`grep -E '^processor[        ]*:' /proc/cpuinfo | wc -l`
+fi
+if test -z "$ncpus" ; then
+    ncpus=1
 fi
 
 cd $dir
