@@ -65,7 +65,7 @@ void RclMain::viewUrl()
        inside internfile and have some url magic to indicate the
        appropriate indexer/identification scheme */
     string udi;
-    make_udi(qs2path(qurl.path()), qs2path(qurl.fragment()), udi);
+    fileUdi::make_udi(qs2path(qurl.path()), qs2path(qurl.fragment()), udi);
     
     Rcl::Doc doc;
     Rcl::Doc idxdoc; // idxdoc.idxi == 0 -> works with base index only
@@ -96,7 +96,7 @@ void RclMain::viewUrl()
         // prevent the temp file deletion completely, leaving it
         // around forever. Better to let the user save a copy if he
         // wants I think.
-        sleep(60);
+        millisleep(60*1000);
         fileExit();
     }
 }
@@ -382,7 +382,7 @@ void RclMain::startNativeViewer(Rcl::Doc doc, int pagenum, QString qterm, int li
     // If we are not called with a page number (which would happen for a call from the snippets
     // window), see if we can compute a page number anyway. 
     if (m_source &&
-        ((pagenum == -1 && pagenumNeeded(cmd)) || termNeeded(cmd)|| linenumNeeded(cmd))) {
+        ((pagenum == -1 && pagenumNeeded(cmd)) || (term.empty() && termNeeded(cmd)))) {
         pagenum = m_source->getFirstMatchPage(doc, term);
     }
     if (pagenum < 0)
