@@ -69,7 +69,7 @@ bool dump_contents(RclConfig *rclconfig, Rcl::Doc& idoc)
 }
 
 std::string make_abstract(Rcl::Doc& doc, Rcl::Query& query, bool asSnippets,
-                     int snipcount, bool showlines, HighlightData& hldata)
+                     int snipcount, bool showlines, HighlightData&)
 {
     std::vector<Rcl::Snippet> snippets;
     std::ostringstream str;
@@ -255,7 +255,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
             // GUI: -f same
         case 'f': op_flags |= OPT_f; break;
             // GUI: -h same
-        case 'h': Usage(std::cout); // Usage exits
+        case 'h': Usage(std::cout); break; // Usage exits. break to avoid warnings
         case 'i': extra_dbs.push_back(optarg); break;
             // GUI uses -L to set language of messages
             // GUI: -l specifies query language, which is the default. Accept and ignore
@@ -376,7 +376,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
         std::string uq;
         std::string charset = rclconfig->getDefCharset(true);
         int ercnt;
-        if (!transcode(qs, uq, charset, "UTF-8", &ercnt)) {
+        if (!transcode(qs, uq, charset, cstr_utf8, &ercnt)) {
             std::cerr << "Can't convert command line args to utf-8\n";
             return 1;
         } else if (ercnt) {
@@ -470,7 +470,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
         }
 
         if (op_flags & OPT_e) 
-            doc.url = url_encode(doc.url);
+            doc.url = path_pcencode(doc.url);
 
         if (op_flags & OPT_b) {
             cout << (paths_only ? doc.url.substr(7) : doc.url) << "\n";
