@@ -24,6 +24,8 @@
  */
 #include "autoconfig.h"
 
+#include "daterange.h"
+
 #include <stdio.h>
 
 #include <vector>
@@ -33,7 +35,7 @@
 #include "log.h"
 #include "rclconfig.h"
 #include "smallut.h"
-#include "daterange.h"
+#include "rclutil.h"
 
 using namespace std;
 
@@ -55,7 +57,7 @@ static inline void bufprefix(char *buf, string pre)
     }
 }
 
-static inline int bpoffs(string pre) 
+static inline size_t bpoffs(string pre) 
 {
     return o_index_stripchars ? pre.length() : pre.length()+2;
 }
