@@ -21,6 +21,7 @@
 #include <algorithm>
 #include <regex>
 
+//#define LOGGER_LOCAL_LOGINC 3
 #include "log.h"
 #include "rcldb.h"
 #include "rcldb_p.h"
@@ -38,9 +39,9 @@ using namespace std;
 
 #undef DEBUGABSTRACT  
 #ifdef DEBUGABSTRACT
-#define LOGABS LOGDEB
+#define LOGABS LOGINF
 #else
-#define LOGABS LOGDEB2
+#define LOGABS LOGDEB1
 #endif
 
 // We now let plaintorich do the highlight tags insertions which is
@@ -79,8 +80,8 @@ static string fixfrag(const string& infrag)
 // matched term weights and the near/phrase matches get a boost.
 struct MatchFragment {
     // Start/End byte offsets of fragment in the document text
-    int start;
-    int stop;
+    size_t start;
+    size_t stop;
     // Weight for this fragment (bigger better)
     double coef;
 #ifdef COMPUTE_HLZONES
@@ -88,19 +89,19 @@ struct MatchFragment {
     // terms). Because a fragment extends around a match, there
     // can be several contiguous or separate matches in a given
     // fragment.
-    vector<pair<int,int>> hlzones;
+    vector<pair<size_t,size_t>> hlzones;
 #endif
     // Position of the first matched term (for page number computations)
-    unsigned int hitpos;
+    size_t hitpos;
     // "best term" for this match (e.g. for use as ext app search term)
     string term;
     int line;
     
-    MatchFragment(int sta, int sto, double c,
+    MatchFragment(size_t sta, size_t sto, double c,
 #ifdef COMPUTE_HLZONES
-                  vector<pair<int,int>>& hl,
+                  vector<pair<size_t,size_t>>& hl,
 #endif
-                  unsigned int pos, string& trm, int ln) 
+                  size_t pos, string& trm, int ln) 
         : start(sta), stop(sto), coef(c), hitpos(pos), line(ln) {
 #ifdef COMPUTE_HLZONES
         hlzones.swap(hl);
@@ -138,14 +139,14 @@ public:
         }
     }
 
-    virtual void newline(int) override {
+    virtual void newline(size_t) override {
         m_line++;
     }
 
     // Accept a word and its position. If the word is a matched term,
     // add/update fragment definition.
-    virtual bool takeword(const std::string& term, int pos, int bts, int bte) override {
-        LOGDEB1("takeword: [" << term << "] bytepos: "<< bts << ":" << bte << "\n");
+    virtual bool takeword(const std::string& term, size_t pos, size_t bts, size_t bte) override {
+        //LOGABS("abs:takeword: [" << term << "] pos " << pos << " bpos: "<< bts << ":" << bte << "\n");
         // Limit time taken with monster documents. The resulting abstract will be incorrect or
         // inexistent, but this is better than taking forever (the default cutoff value comes from
         // the snippetMaxPosWalk configuration parameter, and is 10E6)
@@ -161,14 +162,14 @@ public:
             return false;
         }
         // Remember recent past
-        m_prevterms.push_back(pair<int,int>(bts,bte));
+        m_prevterms.push_back({bts, bte});
         if (m_prevterms.size() > m_ctxwords+1) {
             m_prevterms.pop_front();
         }
 
         string dumb;
         if (o_index_stripchars) {
-            if (!unacmaybefold(term, dumb, "UTF-8", UNACOP_UNACFOLD)) {
+            if (!unacmaybefold(term, dumb, UNACOP_UNACFOLD)) {
                 LOGINFO("abstract: unac failed for [" << term << "]\n");
                 return true;
             }
@@ -179,9 +180,9 @@ public:
         if (m_terms.find(dumb) != m_terms.end()) {
             PRETEND_USE(m_rawtext);
             // This word is a search term. Extend or create fragment
-            LOGDEB1("match: [" << dumb << "] pos " << pos << " bpos " << bts <<
+            LOGABS("match: [" << dumb << "] pos " << pos << " bpos " << bts <<
                     ":" << bte << " remainingWords " << m_remainingWords << "\n");
-            LOGDEB1("Match text " << m_rawtext.substr(bts, bte - bts) << "\n");
+            LOGABS("Match text " << m_rawtext.substr(bts, bte - bts) << "\n");
             double coef = m_wordcoefs[dumb];
             if (!m_remainingWords) {
                 // No current fragment. Start one
@@ -189,19 +190,19 @@ public:
                 m_curfrag.first = m_prevterms.front().first;
                 m_curfrag.second = m_prevterms.back().second;
 #ifdef COMPUTE_HLZONES
-                m_curhlzones.push_back(pair<int,int>(bts, bte));
+                m_curhlzones.push_back(pair<size_t,size_t>(bts, bte));
 #endif
                 m_curterm = term;
                 m_curtermcoef = coef;
                 m_curfragline = m_line;
             } else {
-                LOGDEB2("Extending current fragment: "<<m_remainingWords<<" -> "<<m_ctxwords<< "\n");
+                LOGABS("Extending current fragment: "<<m_remainingWords<<" -> "<<m_ctxwords<< "\n");
                 m_extcount++;
 #ifdef COMPUTE_HLZONES
                 if (m_prevwordhit) {
                     m_curhlzones.back().second = bte;
                 } else {
-                    m_curhlzones.push_back(pair<int,int>(bts, bte));
+                    m_curhlzones.push_back(pair<size_t,size_t>(bts, bte));
                 }
 #endif
                 if (coef > m_curtermcoef) {
@@ -226,8 +227,8 @@ public:
             if (m_gterms.find(dumb) != m_gterms.end()) {
                 // Term group (phrase/near) handling
                 m_plists[dumb].push_back(pos);
-                m_gpostobytes[pos] = pair<int,int>(bts, bte);
-                LOGDEB1("Recorded bpos for pos " << pos << ": " << bts << " " << bte << "\n");
+                m_gpostobytes[pos] = {bts, bte};
+                LOGABS("Recorded bpos for pos " << pos << ": " << bts << " " << bte << "\n");
             }
         }
 #ifdef COMPUTE_HLZONES
@@ -243,9 +244,9 @@ public:
             m_remainingWords--;
             m_curfrag.second = bte;
             if (m_remainingWords == 0) {
-                LOGDEB1("FRAGMENT: from byte " << m_curfrag.first <<
+                LOGABS("FRAGMENT: from byte " << m_curfrag.first <<
                         " to  byte " << m_curfrag.second << "\n");
-                LOGDEB1("FRAGMENT TEXT [" << m_rawtext.substr(
+                LOGABS("FRAGMENT TEXT [" << m_rawtext.substr(
                             m_curfrag.first, m_curfrag.second-m_curfrag.first) << "]\n");
                 // We used to not push weak fragments if we had a lot already. This can cause
                 // problems if the fragments we drop are actually group fragments (which have not
@@ -326,7 +327,7 @@ public:
         }
         auto fragit = m_fragments.begin();
         for (const auto& grpmatch : tboffs) {
-            LOGDEB2("LOOKING FOR FRAGMENT: group: " << grpmatch.offs.first << "-" <<
+            LOGABS("LOOKING FOR FRAGMENT: group: " << grpmatch.offs.first << "-" <<
                     grpmatch.offs.second<<" curfrag "<<fragit->start<<"-"<<fragit->stop<<"\n");
             while (fragit->stop < grpmatch.offs.first) {
                 fragit++;
@@ -350,9 +351,9 @@ public:
 private:
     const string& m_rawtext;
     // Past terms because we need to go back for context before a hit
-    deque<pair<int,int>>  m_prevterms;
+    deque<pair<size_t, size_t>>  m_prevterms;
     // Data about the fragment we are building
-    pair<int,int> m_curfrag{0,0};
+    pair<size_t, size_t> m_curfrag{0,0};
     int m_curfragline{0};
     double m_curfragcoef{0.0};
     unsigned int m_remainingWords{0};
@@ -364,7 +365,7 @@ private:
     // Current sum of fragment weights
     double m_totalcoef{0.0};
     // Position of 1st term match (for page number computations)
-    unsigned int m_curhitpos{0};
+    size_t m_curhitpos{0};
     // "best" term
     string m_curterm;
     double m_curtermcoef{0.0};
@@ -373,8 +374,8 @@ private:
     // Group terms, extracted from m_hdata 
     unordered_set<string> m_gterms;
     // group/near terms word positions.
-    unordered_map<string, vector<int> > m_plists;
-    unordered_map<int, pair<int, int> > m_gpostobytes;
+    unordered_map<string, vector<size_t>> m_plists;
+    unordered_map<size_t, pair<size_t, size_t> > m_gpostobytes;
     
     // Input
     unordered_set<string> m_terms;
@@ -484,7 +485,7 @@ int Query::Native::abstractFromText(
 #endif
         int page = 0;
         if (vpbreaks.size() > 1) {
-            page = ndb->getPageNumberForPosition(vpbreaks, entry.hitpos);
+            page = ndb->getPageNumberForPosition(vpbreaks, static_cast<int>(entry.hitpos));
             if (page < 0)
                 page = 0;
         }
@@ -499,22 +500,24 @@ int Query::Native::abstractFromText(
 class TermLineSplitter : public TextSplit {
 public:
     TermLineSplitter(const std::string& term)
-        : TextSplit(TextSplit::TXTS_NOSPANS), m_term(term) {
+        : TextSplit(), m_term(term) {
+        LOGDEB1("TermLineSplitter: m_term " << m_term << "\n");
     }
-    bool takeword(const std::string& _term, int, int, int) override {
+    bool takeword(const std::string& _term, size_t, size_t, size_t) override {
         std::string term;
         if (o_index_stripchars) {
-            if (!unacmaybefold(_term, term, "UTF-8", UNACOP_UNACFOLD)) {
+            if (!unacmaybefold(_term, term, UNACOP_UNACFOLD)) {
                 LOGINFO("PlainToRich::takeword: unac failed for [" << term << "]\n");
                 return true;
             }
         }
+        LOGDEB1("TermLineSplitter: checking term " << term << "\n");
         if (term == m_term) {
             return false;
         }
         return true;
     }
-    void newline(int) override {
+    void newline(size_t) override {
         m_line++;
     }
     int getline() {
