@@ -324,7 +324,7 @@ bool SearchData::toNativeQuery(Rcl::Db &db, void *d)
 // the time, the result of our splitting will be a single term.
 class TextSplitQ : public TextSplitP {
 public:
-    TextSplitQ(Flags flags, TermProc *prc)
+    TextSplitQ(int flags, TermProc *prc)
         : TextSplitP(prc, flags), m_nostemexp(false) {
     }
 
@@ -336,12 +336,21 @@ public:
 
         return TextSplitP::takeword(term, pos, bs, be);
     }
+    virtual bool discarded(const std::string &term, size_t, size_t, size_t, DiscardReason reason)
+        override {
+        m_problemterm = term;
+        return true;
+    }
 
     bool nostemexp() const {
         return m_nostemexp;
     }
+    std::string getproblemterm() {
+        return m_problemterm;
+    }
 private:
     bool m_nostemexp;
+    std::string m_problemterm;
 };
 
 class TermProcQ : public TermProc {
@@ -580,9 +589,7 @@ void SearchDataClauseSimple::processSimpleSpan(
 {
     vector<Xapian::Query>& pqueries(*(vector<Xapian::Query>*)pq);
     LOGDEB0("StringToXapianQ::processSimpleSpan: [" << span << "] mods 0x"
-            << (unsigned int)mods << "\n");
-    vector<string> exp;  
-    string sterm; // dumb version of user term
+           << (unsigned int)mods << "\n");
 
     string prefix;
     const FieldTraits *ftp;
@@ -592,9 +599,22 @@ void SearchDataClauseSimple::processSimpleSpan(
         prefix = wrap_prefix(ftp->pfx);
     }
 
+    vector<string> exp;  
+    string sterm; // dumb version of user term
     vector<string> multiwords;
-    if (!expandTerm(db, ermsg, mods, span, exp, sterm, prefix, &multiwords))
-        return;
+    static string wildcardchars{"*?[]"};
+    // Special case: in case nowildexp is set and we get a single char (because it's in
+    // indexedpunctuation probably), check if it's a wildcard and don't do expandTerm at
+    // all. Simpler than dealing with the case inside expandTerm.
+    if (getNoWildExp() && span.size() == 1 && wildcardchars.find(span[0]) != string::npos) {
+        exp.push_back(span);
+        sterm = span;
+    } else {
+        if (!expandTerm(db, ermsg, mods, span, exp, sterm, prefix, &multiwords)) {
+            LOGINF("processSimpleSpan: expandterm failed\n");
+            return;
+        }
+    }
     
     // Set up the highlight data. No prefix should go in there
     if (!m_exclude) {
@@ -622,9 +642,8 @@ void SearchDataClauseSimple::processSimpleSpan(
         (m_parentSearch && !m_parentSearch->haveWildCards()) || 
         (nullptr == m_parentSearch && !m_haveWildCards);
     if (exp.size() > 1 && doBoostUserTerm && !sterm.empty()) {
-        xq = Xapian::Query(Xapian::Query::OP_OR, xq, 
-                           Xapian::Query(prefix+sterm, 
-                                         original_term_wqf_booster));
+        xq = Xapian::Query(Xapian::Query::OP_OR, xq,
+                           Xapian::Query(prefix+sterm, original_term_wqf_booster));
     }
 
     // Push phrases for the multi-word expansions
@@ -669,6 +688,8 @@ void SearchDataClauseSimple::processPhraseOrNear(
         orqueries.push_back(Xapian::Query(prefix + start_of_field_term));
     }
 
+    // Max term count in a multiword. See below comment about slack adjustment
+    int maxmwordlen = 0;
     // Go through the list and perform stem/wildcard expansion for each element
     auto nxit = splitData->nostemexps().begin();
     for (auto it = splitData->terms().begin(); it != splitData->terms().end(); it++, nxit++) {
@@ -686,12 +707,20 @@ void SearchDataClauseSimple::processPhraseOrNear(
         if (!expandTerm(db, ermsg, lmods, *it, exp, sterm, prefix, &multiwords))
             return;
 
-        // Note: because of how expandTerm works, the multiwords can
-        // only come from the synonyms expansion, which means that, if
-        // idxsynonyms is set, they have each been indexed as a single
-        // term. So, if idxsynonyms is set, and is the current active
-        // synonyms file, we just add them to the expansion.
+        // Note: because of how expandTerm works, the multiwords can only come from the synonyms
+        // expansion, which means that, if idxsynonyms is set, they have each been indexed as a
+        // single term. So, if idxsynonyms is set, and is the current active synonyms file, we just
+        // add them to the expansion. We have to increase the slack in this case, which will also
+        // apply to single-word expansions and cause false matches, but this is better than missing
+        // multiword matches (this is because, even if the multiword term was issued at the position
+        // of its first word during indexing, the position of the first term after the multiword is
+        // still increased by the number of words in the multiword).
         if (!multiwords.empty() && useidxsynonyms) {
+            for (const auto& mword: multiwords) {
+                int cnt = std::count(mword.begin(), mword.end(), ' ') + 1;
+                if (cnt > maxmwordlen)
+                    maxmwordlen = cnt;
+            }
             exp.insert(exp.end(), multiwords.begin(), multiwords.end());
         }
 
@@ -717,6 +746,9 @@ void SearchDataClauseSimple::processPhraseOrNear(
     // For phrases, give a relevance boost like we do for original terms
     LOGDEB2("PHRASE/NEAR:  alltermcount " << splitData->alltermcount() <<
             " lastpos " << splitData->lastpos() << "\n");
+    if (maxmwordlen > 1) {
+        slack += maxmwordlen - 1;
+    }
     Xapian::Query xq(op, orqueries.begin(), orqueries.end(),
                      static_cast<int>(orqueries.size()) + slack);
     if (op == Xapian::Query::OP_PHRASE)
@@ -780,7 +812,7 @@ static int stringToMods(string& s)
  *   count)
  */
 bool SearchDataClauseSimple::processUserString(
-    Rcl::Db &db, const string &iq, string &ermsg, void *pq, int slack0, bool useNear)
+    Rcl::Db &db, const string &iq, string &ermsg, string &pbterm, void *pq, int slack0, bool useNear)
 {
     vector<Xapian::Query> &pqueries(*(vector<Xapian::Query>*)pq);
     int mods = m_modifiers;
@@ -836,11 +868,16 @@ bool SearchDataClauseSimple::processUserString(
             if (o_index_stripchars)
                 nxt = &tpprep;
 
-            TextSplitQ splitter(TextSplit::Flags(
-                                    TextSplit::TXTS_ONLYSPANS | TextSplit::TXTS_KEEPWILD), nxt);
+            int txtsplitflags = TextSplit::TXTS_ONLYSPANS;
+            if (!getNoWildExp()) {
+                txtsplitflags |= TextSplit::TXTS_KEEPWILD;
+            }
+            TextSplitQ splitter(txtsplitflags, nxt);
             tpq.setTSQ(&splitter);
             splitter.text_to_words(wordorphrase);
-
+            if (!splitter.getproblemterm().empty()) {
+                pbterm = splitter.getproblemterm();
+            }
             slack += tpq.lastpos() - int(tpq.terms().size()) + 1;
 
             LOGDEB0("strToXapianQ: termcount: " << tpq.terms().size() << "\n");
@@ -933,12 +970,15 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p)
     }
 
     vector<Xapian::Query> pqueries;
-    if (!processUserString(db, m_text, m_reason, &pqueries))
+    std::string pbterm;
+    if (!processUserString(db, m_text, m_reason, pbterm, &pqueries))
         return false;
     if (pqueries.empty()) {
-        LOGERR("SearchDataClauseSimple: resolved to null query\n");
-        m_reason = string("Resolved to null query. Term too long ? : [" + 
-                          m_text + string("]"));
+        LOGDEB("SearchDataClauseSimple: " << m_text << " resolved to null query\n");
+        if (!pbterm.empty()) 
+            m_reason = string("Resolved to null query. Problem term : [" + pbterm + string("]"));
+        else
+            m_reason = string("Resolved to null query. Term too long ? : [" + m_text + string("]"));
         return false;
     }
 
@@ -1106,12 +1146,16 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p)
         // quoted word because processUserString won't see it as a phrase by itself.
         m_modifiers |= SDCM_NOSTEMMING;
     }
-    if (!processUserString(db, s, m_reason, &pqueries, m_slack, useNear))
+    string pbterm;
+    if (!processUserString(db, s, m_reason, pbterm, &pqueries, m_slack, useNear))
         return false;
     if (pqueries.empty()) {
-        LOGERR("SearchDataClauseDist: resolved to null query\n");
-        m_reason = string("Resolved to null query. Term too long ? : [" +  m_text + string("]"));
-        return false;
+        LOGDEB("SearchDataClauseDist: [" << s << "]resolved to null query\n");
+        if (!pbterm.empty()) 
+            m_reason = string("Resolved to null query. Problem term : [" + pbterm + string("]"));
+        else
+            m_reason = string("Resolved to null query. Term too long ? : [" + m_text + string("]"));
+        return true;
     }
 
     *qp = *pqueries.begin();
