@@ -15,6 +15,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  *   02110-1301 USA
  */
+#ifdef BUILDING_RECOLL
+#include "autoconfig.h"
+#else
+#include "config.h"
+#endif
+
 #include "smallut.h"
 
 #include <algorithm>
@@ -44,17 +50,135 @@
 #include <regex>
 #endif
 
-#ifdef _MSC_VER
-#define strncasecmp _strnicmp
-#define strcasecmp _stricmp
-#define localtime_r(a,b) localtime_s(b,a)
-#endif // _MSC_VER
 
+#ifdef _WIN32
+
+#define WIN32_LEAN_AND_MEAN
+#define NOGDI
+#include <windows.h>
+#include <stringapiset.h>
+
+#endif // _WIN32
+
+#ifdef MDU_INCLUDE_LOG
+#include MDU_INCLUDE_LOG
+#else
+#include "log.h"
+#endif
 
 using namespace std::placeholders;
 
 namespace MedocUtils {
 
+#ifdef _WIN32
+
+std::string wchartoutf8(const wchar_t *in, int len)
+{
+    std::string out;
+    wchartoutf8(in, out, len);
+    return out;
+}
+
+bool wchartoutf8(const wchar_t *in, std::string& out, int wlen)
+{
+    out.clear();
+    if (nullptr == in) {
+        return true;
+    }
+    if (wlen == 0) {
+        wlen = static_cast<int>(wcslen(in));
+    }
+    if (wlen == 0) {
+        return true;
+    }
+    int flags = WC_ERR_INVALID_CHARS;
+    int bytes = ::WideCharToMultiByte(CP_UTF8, flags, in, wlen, nullptr, 0, nullptr, nullptr);
+    if (bytes <= 0) {
+#ifdef LOGERR
+        LOGERR("wchartoutf8: conversion error1\n");
+#endif
+        fwprintf(stderr, L"wchartoutf8: conversion error1 for [%s]\n", in);
+        return false;
+    }
+    DirtySmartBuf buffer(bytes+1);
+    bytes = ::WideCharToMultiByte(CP_UTF8, flags, in, wlen, buffer.buf(), bytes, nullptr, nullptr);
+    if (bytes <= 0) {
+#ifdef LOGERR
+        LOGERR("wchartoutf8: CONVERSION ERROR2\n");
+#endif
+        return false;
+    }
+    buffer.buf()[bytes] = 0;
+    out = buffer.buf();
+    //fwprintf(stderr, L"wchartoutf8: in: [%s]\n", in);
+    //fprintf(stderr, "wchartoutf8: out:  [%s]\n", out.c_str());
+    return true;
+}
+
+bool utf8towchar(const std::string& in, wchar_t *out, int obytescap)
+{
+    auto wcharsavail = obytescap / sizeof(wchar_t);
+    if (nullptr == out || wcharsavail < 1) {
+        return false;
+    }
+    out[0] = 0;
+    int isize = static_cast<int>(in.size());
+    auto wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), isize, nullptr, 0);
+    if (wcharcnt <= 0) {
+#ifdef LOGERR
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+#endif
+        return false;
+    }
+    if (wcharcnt + 1 >  int(wcharsavail)) {
+#ifdef LOGERR
+        LOGERR("utf8towchar: not enough space\n");
+#endif
+        return false;
+    }
+    wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), isize, out, wcharsavail);
+    if (wcharcnt <= 0) {
+#ifdef LOGERR
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+#endif
+        return false;
+    }
+    out[wcharcnt] = 0;
+    return true;
+}
+
+std::unique_ptr<wchar_t[]> utf8towchar(const std::string& in)
+{
+    int isize = static_cast<int>(in.size());
+    // Note that as we supply in.size(), mbtowch computes the size
+    // without a terminating 0 (and won't write in the second call of
+    // course). We take this into account by allocating one more and
+    // terminating the output.
+    auto wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), isize, nullptr, 0);
+    if (wcharcnt <= 0) {
+#ifdef LOGERR
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+#endif
+        return std::unique_ptr<wchar_t[]>();
+    }
+    auto buf = std::make_unique<wchar_t[]>(wcharcnt+1);
+
+    wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), isize, buf.get(), wcharcnt);
+    if (wcharcnt <= 0) {
+#ifdef LOGERR
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+#endif
+        return std::unique_ptr<wchar_t[]>();
+    }
+    buf[wcharcnt] = 0;
+    return buf;
+}
+#endif // _WIN32
+
 int stringicmp(const std::string& s1, const std::string& s2)
 {
     return strcasecmp(s1.c_str(), s2.c_str());
@@ -302,9 +426,9 @@ template <class T> std::string stringsToString(const T& tokens)
     return out;
 }
 
-template <class T> void stringsToCSV(const T& tokens, std::string& s, char sep)
+template <class T> std::string stringsToCSV(const T& tokens, char sep)
 {
-    s.erase();
+    std::string s;
     for (const auto& tok : tokens) {
         bool needquotes = false;
         if (tok.empty() || tok.find_first_of(std::string(1, sep) + "\"\n") != std::string::npos) {
@@ -328,6 +452,7 @@ template <class T> void stringsToCSV(const T& tokens, std::string& s, char sep)
     // Remove last separator.
     if (!s.empty())
         s.pop_back();
+    return s;
 }
 
 template <class T> std::string commonprefix(const T& values)
@@ -376,10 +501,8 @@ template std::string stringsToString<std::vector<std::string>>(const std::vector
 template std::string stringsToString<std::set<std::string>>(const std::set<std::string>&);
 template std::string stringsToString<std::unordered_set<std::string>>(
     const std::unordered_set<std::string>&);
-template void stringsToCSV<std::list<std::string>>(
-    const std::list<std::string>&, std::string&, char);
-template void stringsToCSV<std::vector<std::string>>(
-    const std::vector<std::string>&, std::string&, char);
+template std::string stringsToCSV<std::list<std::string>>(const std::list<std::string>&, char);
+template std::string stringsToCSV<std::vector<std::string>>(const std::vector<std::string>&, char);
 template std::string commonprefix<std::vector<std::string>>(const std::vector<std::string>&values);
 #endif
 
@@ -441,6 +564,18 @@ void stringSplitString(const std::string& str, std::vector<std::string>& tokens,
     }
 }
 
+std::string tokensToString(const std::vector<std::string>& tokens, const std::string& sep)
+{
+    std::string out;
+    for (const auto& token : tokens) {
+        if (!out.empty()) {
+            out += sep;
+        }
+        out += token;
+    }
+    return out;
+}
+
 bool stringToBool(const std::string& s)
 {
     if (s.empty()) {
@@ -825,8 +960,12 @@ static void unsetenv(const char* name)
 {
     _putenv_s(name, "");
 }
-#endif
-
+#ifdef _MSC_VER
+time_t portable_timegm(struct tm *tm)
+{
+    return _mkgmtime(tm);
+}
+#else
 time_t portable_timegm(struct tm *tm)
 {
     time_t ret;
@@ -844,6 +983,14 @@ time_t portable_timegm(struct tm *tm)
     tzset();
     return ret;
 }
+#endif // End Windows not msvc
+#else // -> !Windows
+time_t portable_timegm(struct tm *tm)
+{
+    return timegm(tm);
+}
+#endif
+
 
 std::string hexprint(const std::string& in, char separ)
 {
@@ -1142,6 +1289,18 @@ bool parseHTTPRanges(const std::string& ranges, std::vector<std::pair<int64_t, i
     return true;
 }
 
+void millisleep(int millis)
+{
+#ifdef _WIN32
+    Sleep(millis);
+#else
+    struct timespec spec;
+    spec.tv_sec = millis / 1000;
+    spec.tv_nsec = (millis % 1000) * 1000000;
+    nanosleep(&spec, nullptr);
+#endif
+}
+
 // Initialization for static stuff to be called from main thread before going
 // multiple
 void smallut_init_mt()
